The `malloc`, `realloc`, `calloc`, `memmove`, `scanf`, `free` ... are functions with dynamic memory handling and allocation. 

Improper calls to these functions can result in memory corruption vulnerabilities that can lead to denial of service,
information leak, arbitrary read and write or remote code execution.
